@@ -5,6 +5,7 @@ import unittest
 from taz.aci import SimpleContainerGroup
 from taz.acr import ContainerRegistry
 from taz.acr import ContainerImage
+from taz.auth import UserAssignedIdentity
 import tests.config as cfg
 import sys
 
@@ -52,6 +53,16 @@ class AciCreateTests(unittest.TestCase):
         print(self.container_group.generic_client.mode)
         print(self.container_group)
 
+    def test_22_user_assigned_identity(self):
+        self.container_group.set_identity(
+            UserAssignedIdentity(
+                cfg.aci["resource_group"],
+                "mi-aci-wag-dev-01",
+                subscription_id=cfg.aci["subscription_id"],
+            )
+        )
+        print(self.container_group)
+
     def test_25_print_group(self):
         print(self.container_group)
 
